@@ -4,8 +4,8 @@ test_that("GET ID de proposição inexistente", {expect_equal(proposicao_inexist
 test_that("GET proposição com ID inexistente", {expect_error(fetch_proposicao(id = 506))})
 
 # Setup
-pec_241 <- fetch_proposicao(siglaTipo = "PEC", numero = 241, ano = 2016)
-pec_241_id <- pec_241$id
+pec_241 <- fetch_proposicao(siglaTipo = "PEC", numero = 241, ano = 2016, dataInicio = "2016-01-01")
+pec_241_id <- fetch_id_proposicao("PEC", 241, 2016)
 pec_241_por_id <- fetch_proposicao(pec_241_id)
 status_pec241 <- fetch_status_proposicao(pec_241_id)
 
@@ -79,3 +79,13 @@ test_that("IDs Votacoes PEC241", {expect_true(r$result)})
 r <- compare::compareEqual(fetch_tipo_proposicao(139)$sigla, "PL")
 test_that("Tipo de proposição", {expect_true(r$result)})
 
+# Testa quantidade de itens por requisição
+test_that("Quantidade de itens por requisição",{
+  expect_equal(dim(fetch_proposicao(dataInicio = "2007-01-01", dataFim = "2017-01-01", itens = 10)), c(10, 7))
+  expect_equal(dim(fetch_proposicao(dataInicio = "2007-01-01", dataFim = "2017-01-01", itens = 100)), c(100, 7))
+  expect_equal(dim(fetch_proposicao(dataInicio = "2007-01-01", dataFim = "2017-01-01", itens = 386)), c(386, 7))
+})
+
+test_that("Quantidade default por requisição, atualmente 15",{
+  expect_equal(dim(fetch_proposicao()), c(15, 7))
+})
